==> 0.3.0.zip: grichelde/localisation/enUS.lua <==
local L = LibStub('AceLocale-3.0'):NewLocale('Grichelde', 'enUS', true)
if not L then return end

-- system messages
L.AddonName = "Grichelde"
L.AddonLoaded = "%s now helps you with your spelling disabilities."
L.Addon_Detected_Misspelled = "Addon 'Misspelled' has been detected and any messsage will be cleansed automatically."
L.Addon_Detected_WIM = "Das Addon 'WIM' has been detected and any whispers will be handled from IM windows."


-- profiles
L.Profiles_Available = "Available profiles:"
L.Profiles_Created = "New profile \"%s\" created."
L.Profiles_Loaded = "Profile %s%s%s is loaded."
L.Profiles_Refreshed = "Profil %s%s%s refreshed."
L.Profiles_Deleted = "Profile %s%s%s deleted."
L.Profiles_Copied = "Settings applied from profile %s%s%s."
L.Profiles_Reset = "Profil %s%s%s reset."
L.Profiles_Invalid = "Invalid profile %s%s%s!"
L.Profiles_DeleteError = "The active profile cannot be deleted!"

-- options
L.Options_Title = "%s Options"
L.Options_Enabled_Name = "Enabled"
L.Options_Enabled_Desc = "Enables %s"

L.Options_Channels_Group_Name = "Channels"
L.Options_Channels_Group_Desc = "%s is active in the following channels."
L.Options_Channels_ChannelSay_Name = "Say"
L.Options_Channels_ChannelSay_Desc = "Activates %s in channel \"Say\"."
L.Options_Channels_ChannelEmote_Name = "Emote"
L.Options_Channels_ChannelEmote_Desc = "Activates %s in channel \"Emote\"."
L.Options_Channels_ChannelYell_Name = "Yell"
L.Options_Channels_ChannelYell_Desc = "Activates %s in channel \"Yell\"."
L.Options_Channels_ChannelParty_Name = "Party"
L.Options_Channels_ChannelParty_Desc = "Activates %s in channel \"Party\"."
L.Options_Channels_ChannelPartyLeader_Name = "Party Leader"
L.Options_Channels_ChannelPartyLeader_Desc = "Activates %s in channel \"Party Leader\"."
L.Options_Channels_ChannelGuild_Name = "Guild"
L.Options_Channels_ChannelGuild_Desc = "Activates %s in channel \"Guild\"."
L.Options_Channels_ChannelOfficer_Name = "Officers"
L.Options_Channels_ChannelOfficer_Desc = "Activates %s in channel \"Officers\"."
L.Options_Channels_ChannelRaid_Name = "Raid"
L.Options_Channels_ChannelRaid_Desc = "Activates %s in channel \"Raid\"."
L.Options_Channels_ChannelRaidLeader_Name = "Raid Leader"
L.Options_Channels_ChannelRaidLeader_Desc = "Activates %s in channel \"Raid Leader\"."
L.Options_Channels_ChannelInstance_Name = "Instance"
L.Options_Channels_ChannelInstance_Desc = "Activates %s in channel \"Instance\"."
L.Options_Channels_ChannelBattleground_Name = "Battleground"
L.Options_Channels_ChannelBattleground_Desc = "Activates %s in channel \"Battleground\"."
L.Options_Channels_ChannelWhisper_Name = "Whisper"
L.Options_Channels_ChannelWhisper_Desc = "Activates %s in channel \"Whisper\"."

L.Options_Replacements_Group_Name = "Replacements"
L.Options_Replacements_Group_Desc = "These lookups will be replaced in activated channels."
L.Options_Replacements_Add_Name = "Add"
L.Options_Replacements_Add_Desc = "Add a new replacement mapping."
L.Options_Replacements_DeleteAll_Name = "Delete All"
L.Options_Replacements_DeleteAll_Desc = "Delete all replacement mappings."

L.Options_Replacement_Group_Name = "Mapping"
L.Options_Replacement_Group_Desc = "This lookup will be replaced in activated channels."
L.Options_Replacement_SearchText_Name = "Search for:"
L.Options_Replacement_SearchText_Desc = "This text is looked up in your chat input box."
L.Options_Replacement_ReplaceText_Name = "Replacement:"
L.Options_Replacement_ReplaceText_Desc = "Any match will be replaced with this text."
L.Options_Replacement_CaseSensitive_Name = "case sensitive"
L.Options_Replacement_CaseSensitive_Desc = "Will not replace occurrences if cases differ."
L.Options_Replacement_Consolidate_Name = "consolidate consecutive matches"
L.Options_Replacement_Consolidate_Desc = "If after the replacement a text sequence is repeated|ndirectly after another, treat them as one occurrence."
L.Options_Replacement_Delete_Name = "Delete"
L.Options_Replacement_Delete_Desc = "Delete this replacement mapping."

==> 0.5.0.zip: grichelde/localisation/enUS.lua <==
local L = LibStub('AceLocale-3.0'):NewLocale('Grichelde', 'enUS', true)
if not L then return end

-- system messages
L.AddonName = "Grichelde"
L.VersionAbbr = "v"
L.AddonLoaded = "%s now helps you with your spelling disabilities."
L.Addon_Detected_Misspelled = "The Addon 'Misspelled' has been detected and any messsage will be cleansed automatically."
L.Addon_Detected_WIM = "The Addon 'WIM' has been detected and any whispers will be handled from IM windows."


-- profiles
L.Profiles_Available = "Available profiles:"
L.Profiles_Created = "New profile %s created."
L.Profiles_Loaded = "Profile %s is loaded."
L.Profiles_Refreshed = "Profil %s refreshed."
L.Profiles_Deleted = "Profile %s deleted."
L.Profiles_Copied = "Settings applied from profile %s."
L.Profiles_Reset = "Profil %s reset."
L.Profiles_Invalid = "Invalid profile %s!"
L.Profiles_DeleteError = "The active profile cannot be deleted!"

-- options
L.Options_Title = "%s Options"
L.Options_Enabled_Name = "Enabled"
L.Options_Enabled_Desc = "Enables %s"

L.Options_Channels_Group_Name = "Channels"
L.Options_Channels_Group_Desc = "%s is active in the following channels."
L.Options_Channels_ChannelSay_Name = "Say"
L.Options_Channels_ChannelSay_Desc = "Activates %s in channel \"Say\"."
L.Options_Channels_ChannelEmote_Name = "Emote"
L.Options_Channels_ChannelEmote_Desc = "Activates %s in channel \"Emote\"."
L.Options_Channels_ChannelYell_Name = "Yell"
L.Options_Channels_ChannelYell_Desc = "Activates %s in channel \"Yell\"."
L.Options_Channels_ChannelParty_Name = "Party"
L.Options_Channels_ChannelParty_Desc = "Activates %s in channel \"Party\"."
L.Options_Channels_ChannelPartyLeader_Name = "Party Leader"
L.Options_Channels_ChannelPartyLeader_Desc = "Activates %s in channel \"Party Leader\"."
L.Options_Channels_ChannelGuild_Name = "Guild"
L.Options_Channels_ChannelGuild_Desc = "Activates %s in channel \"Guild\"."
L.Options_Channels_ChannelOfficer_Name = "Officers"
L.Options_Channels_ChannelOfficer_Desc = "Activates %s in channel \"Officers\"."
L.Options_Channels_ChannelRaid_Name = "Raid"
L.Options_Channels_ChannelRaid_Desc = "Activates %s in channel \"Raid\"."
L.Options_Channels_ChannelRaidLeader_Name = "Raid Leader"
L.Options_Channels_ChannelRaidLeader_Desc = "Activates %s in channel \"Raid Leader\"."
L.Options_Channels_ChannelRaidWarning_Name = "Raid Warning"
L.Options_Channels_ChannelRaidWarning_Desc = "Activates %s in channel \"Raid Warning\"."
L.Options_Channels_ChannelInstance_Name = "Instance"
L.Options_Channels_ChannelInstance_Desc = "Activates %s in channel \"Instance\"."
L.Options_Channels_ChannelBattleground_Name = "Battleground"
L.Options_Channels_ChannelBattleground_Desc = "Activates %s in channel \"Battleground\"."
L.Options_Channels_ChannelWhisper_Name = "Whisper"
L.Options_Channels_ChannelWhisper_Desc = "Activates %s in channel \"Whisper\"."

L.Options_Replacements_Group_Name = "Replacements"
L.Options_Replacements_Group_Desc = "These lookups will be replaced in activated channels."
L.Options_Replacements_Add_Name = "Add"
L.Options_Replacements_Add_Desc = "Adds a new replacement mapping."
L.Options_Replacements_DeleteAll_Name = "Delete All"
L.Options_Replacements_DeleteAll_Desc = "Deletes all replacement mappings."
L.Options_Replacements_DeleteAll_ConfirmText = "Do you really want to delete ALL replacement mappings?"

L.Options_Replacement_Group_Name = "%s => %s"
L.Options_Replacement_Group_Desc = "This lookup will be replaced in activated channels."
L.Options_Replacement_EmptyMapping = "(none)"
L.Options_Replacement_SearchText_Name = "Search for:"
L.Options_Replacement_SearchText_Desc = "This text is looked up in your chat input box."
L.Options_Replacement_ReplaceText_Name = "Replacement:"
L.Options_Replacement_ReplaceText_Desc = "Any match will be replaced with this text."
L.Options_Replacement_CaseSensitive_Name = "case sensitive"
L.Options_Replacement_CaseSensitive_Desc = "Will not replace occurrences if cases differ."
L.Options_Replacement_Consolidate_Name = "consolidate consecutive matches"
L.Options_Replacement_Consolidate_Desc = "If after the replacement a text sequence is repeated|ndirectly after another, treat them as one occurrence."
L.Options_Replacement_Delete_Name = "Delete"
L.Options_Replacement_Delete_Desc = "Deletes this replacement mapping."
L.Options_Replacements_Delete_ConfirmText = "Delete this replacement mapping?"
